@@ -4,7 +4,6 @@
 
 import os
 import re
-import time
 
 from socket import gethostname
 
@@ -54,51 +53,6 @@ class FileWatcher(object):
                 self._callback()
 
 
-class ApprcWatcher(CircusPlugin):
-    name = "apprc_watcher"
-
-    def __init__(self, *args, **config):
-        super(ApprcWatcher, self).__init__(*args, **config)
-        self.loop_rate = int(config.get("loop_rate", 3))
-        self.apprc = config.get("apprc", "/home/application/apprc")
-        self.port = config.get("port", "8888")
-        self.period = ioloop.PeriodicCallback(
-            FileWatcher(self.apprc, self.reload_env),
-            self.loop_rate * 1000,
-            self.loop
-        )
-
-    def handle_init(self):
-        self.period.start()
-
-    def handle_stop(self):
-        self.period.stop()
-
-    def handle_recv(self, data):
-        pass
-
-    def reload_env(self):
-        envs = {"port": self.port, "PORT": self.port}
-        envs.update(common.load_envs(self.apprc))
-        for name in self.cmds():
-            if not name.startswith("plugin:"):
-                self.add_envs(name, envs)
-
-    def add_envs(self, name, envs):
-        current = self.call("options", name=name)["options"]["env"]
-        values = {}
-        values.update(os.environ, **envs)
-        if "PYTHONPATH" in values and "PYTHONPATH" not in envs:
-            del values["PYTHONPATH"]
-        if values != current:
-            self.call("stop", name=name, waiting=True)
-            self.call("set", name=name, options={"env": values})
-            self.call("start", name=name, waiting=True)
-
-    def cmds(self):
-        return self.call("status")["statuses"].keys()
-
-
 class WatcherCreationError(Exception):
     pass
 
@@ -108,6 +62,7 @@ class ProcfileWatcher(CircusPlugin):
 
     def __init__(self, *args, **config):
         super(ProcfileWatcher, self).__init__(*args, **config)
+        self.loop_rate = int(config.get("loop_rate", 3))
         self.procfile_path = config.get("app_path",
                                         "/home/application/current/Procfile")
         self.working_dir = config.get("working_dir",
@@ -120,22 +75,20 @@ class ProcfileWatcher(CircusPlugin):
                                                   "tsuru.stream.Stream")}
         self.stdout_stream = {"class": config.get("stdout_stream",
                                                   "tsuru.stream.Stream")}
-        self.ran = False
+        self.period = ioloop.PeriodicCallback(
+            FileWatcher(self.apprc, self.reload_procfile),
+            self.loop_rate * 1000,
+            self.loop
+        )
 
     def handle_init(self):
-        pass
+        self.period.start()
 
     def handle_stop(self):
-        pass
+        self.period.stop()
 
     def handle_recv(self, data):
-        while not self.ran:
-            try:
-                self.reload_procfile()
-                self.ran = True
-                break
-            except:
-                time.sleep(1)
+        pass
 
     def load_envs(self):
         env = {"port": self.port, "PORT": self.port}
@@ -167,8 +120,6 @@ class ProcfileWatcher(CircusPlugin):
 
     def commands(self, procfile):
         cmds = self.call("status")["statuses"]
-        if "tsuru-hooks" in cmds:
-            del cmds["tsuru-hooks"]
         cmds_names = set([k for k in cmds.keys()
                           if not k.startswith("plugin:")])
         new_cmds = set(procfile.commands.keys())
@@ -205,8 +156,6 @@ class StatusReporter(CircusPlugin):
 
     def report(self):
         cmds = self.call("status")["statuses"]
-        if "tsuru-hooks" in cmds:
-            del cmds["tsuru-hooks"]
         status = "started"
         for cmd_name, cmd_status in cmds.iteritems():
             if cmd_name.startswith("plugin:"):
