@@ -11,6 +11,8 @@ from circus.util import human2bytes
 
 from tsuru import common
 
+import psutil
+
 
 class StatsdEmitter(CircusPlugin):
     name = 'statsd'
@@ -77,7 +79,27 @@ class Stats(BaseObserver):
 
     name = 'stats'
 
+    def disk_usage(self):
+        return psutil.disk_usage("/").used
+
+    def net_io(self):
+        io = psutil.net_io_counters()
+        return io.bytes_sent, io.bytes_recv
+
+    def connections_established(self):
+        connections = psutil.net_connections("tcp")
+        return sum([1 for conn in connections if conn.status == "ESTABLISHED"])
+
     def look_after(self):
+
+        self.statsd.gauge("disk_usage", self.disk_usage())
+
+        net_sent, net_recv = self.net_io()
+        self.statsd.gauge("net.sent", net_sent)
+        self.statsd.gauge("net.recv", net_recv)
+
+        self.statsd.gauge("net.connections", self.connections_established())
+
         info = self.call("stats")
         if info["status"] == "error":
             self.statsd.increment("_stats.error")
@@ -96,15 +118,16 @@ class Stats(BaseObserver):
                 if isinstance(sub_info, dict):
                     cpu = [sub_info['cpu']]
                     mem = [sub_info['mem']]
+                    inf = [human2bytes(sub_info['mem_info1'])]
 
                     for p in sub_info['children']:
                         cpu.append(p['cpu'])
                         mem.append(p['mem'])
+                        inf.append(human2bytes(p['mem_info1']))
 
                     cpus.append(sum(cpu))
                     mems.append(sum(mem))
-
-                    mem_infos.append(human2bytes(sub_info['mem_info1']))
+                    mem_infos.append(sum(inf))
                 elif sub_name == "spawn_count":
                     # spawn_count info is in the same level as processes
                     # dict infos, so if spawn_count is given, take it and
